Create a exploratory data analysis report in HTML format
ExpReport(data,Template=NULL,Target=NULL,label=NULL,op_file=NULL,
op_dir=getwd(),sc=NULL,sn=NULL,Rc=NULL)a data frame
R markdown template (.rmd file)
dependent variable. If there is no defined target variable then keep as it is NULL.
target variable descriptions, not a mandatory field
output file name (.html)
output path
sample number of plots for categorical variable. User can decide how many number of plots to depict in html report.
sample number of plots for numerical variable. User can decide how many number of plots to depict in html report.
reference category of target variable. If Target is categorical then Pclass value is mandatory and which should not be NULL
The "ExpReport" function will generate a HTML report for any R data frames. If the markdown template is ready, we can use that template to generate the HTML report else It will generate three different types of HTML report based on the Target field
IF Target = NULL, means there is no defined dependent varaible then it will genreate general EDA report at overall level
IF Target = continuous, then it will genreate EDA report including univariate and multivarite summary statistics with correlation.
IF Target = categorical, then it will genreate EDA report including univariate and multivarite summary statistics with chi-square, Information values.